@@ -42,3 +42,16 @@ fn empty_varname_is_error() {
 
     assert!(matches!(err, CompilationError::EmptyVariable));
 }
+
+#[test]
+fn empty_property_name_is_error() {
+    let cu = CaoIr {
+        lanes: vec![
+            Lane::default().with_cards(vec![Card::SetProperty(VarNode::from_str_unchecked(""))])
+        ],
+    };
+
+    let err = compile(cu, CompileOptions::new()).unwrap_err();
+
+    assert!(matches!(err, CompilationError::EmptyVariable));
+}
